@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240628';
+our $VERSION = '0.20240930';
 
-# Table last modified: 2024-06-28
+# Table last modified: 2024-09-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -29,7 +29,7 @@ our %ZIP_TABLE = (
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
     '023' => '(?:(?:049[23]|1192|8501))',
     '024' => '(?:(?:85(?:20|55|0[15-7]|1[0138])|0(?:19[2-5]|392)))',
-    '025' => '(?:(?:8(?:60[12]|501)|039[2-5]))',
+    '025' => '(?:(?:8(?:60[12]|501)|039[235]))',
     '026' => '(?:8(?:5(?:50|67)|686))',
     '027' => '(?:(?:850[1-3]|0595))',
     '028' => '(?:(?:8(?:0(?:4[02]|3[01])|392|696)|7(?:39[2-7]|[15]92|995)|4(?:39[358]|19[35])|(?:0[135]|1[13])92|6(?:19[23568]|892)|3(?:69[2457]|392)|5495))',
@@ -104,18 +104,18 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|3[09]|0[235]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|3(?:8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
+    '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:3[03]|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
+    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:32|81|0[23578]|7[02]|1[146]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|4[035]|8[0-3568])|3(?:2[25689]|3[134]|1[0356]|7[2359]|8[013-689]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|7[056]|4[0-38]|1[0-267]|0[1-36-9]|3[0-4]|5[05]|2[0245])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|71|[01][15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -128,23 +128,23 @@ our %ZIP_TABLE = (
     '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:71|86|4[02]|3[367]|5[05]|2[58]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
-    '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
+    '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
     '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-368]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|55|67|1[025]|0[13]|8[058]|7[67]|4[034])|6(?:[03]1|[15]0|77|2[03]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
-    '151' => '(?:8(?:5(?:[34]\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|5[1-5]|1[0-24-6]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '151' => '(?:8(?:5(?:[34]\d|0[2-7]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|1[02568]|3[01679])|6(?:01|40|1[06]|8[78]|6[025689]|2[026]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
-    '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|3[02369]|6[05-8]|2[0135]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
+    '154' => '(?:8(?:5(?:4[3-5]|3[02369]|6[05-8]|8[0-2459]|2[0135]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
@@ -168,7 +168,7 @@ our %ZIP_TABLE = (
     '177' => '(?:85(?:21|0[1-389]))',
     '178' => '(?:8(?:5(?:11|67|0[12])|6(?:[68]6|01|24)))',
     '179' => '(?:8(?:9(?:0[134679]|1[14])|501))',
-    '180' => '(?:8(?:5(?:66|80|1[79]|2[027]|7[17]|3[138]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
+    '180' => '(?:8(?:5(?:66|80|1[79]|3[13]|2[027]|7[17]|0[58])|6(?:29|33|1[018]|0[28])|7(?:50|77)))',
     '181' => '(?:8(?:5(?:41|67|3[135]|7[17]|8[568]|2[128]|1[178]|0[35]|5[15])|6(?:[04]8|22|33|1[124])|001))',
     '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|70|85|1[1-469]|2[124-689]|5[013]|3[02469]|4[0189]|0[1256])|70[1-35-7]))',
@@ -178,7 +178,7 @@ our %ZIP_TABLE = (
     '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
     '189' => '(?:85(?:[01]1|20|85|5[05]))',
-    '190' => '(?:(?:8(?:5(?:90|2[028]|3[015-79]|5[013-578]|0[135-8]|6[0-256]|8[1-3689]|4[02-4]|1[013-9]|7[1-3589])|6(?:09|66|8[0168]))|129[23578]|0192))',
+    '190' => '(?:(?:8(?:5(?:90|2[028]|3[015-79]|0[135-8]|6[0-256]|8[1-3689]|4[02-4]|1[013-9]|7[1-3589]|5[014578])|6(?:09|66|8[0168]))|129[23578]|0192))',
     '191' => '(?:8(?:5(?:20|0[1-3679]|1[0-2])|6(?:60|86)))',
     '192' => '(?:(?:8(?:5(?:77|85|2[025]|5[01368]|3[235-7]|[16][02568]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-36]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
@@ -195,9 +195,9 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|0[25]|8[568]|1[0-25]|6[167]|5[15])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
-    '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
+    '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|3[178]|4[013-578]|7[067]|1[12]|8[56]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
     '211' => '(?:8(?:5(?:22|66|3[03]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
-    '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[2-4]))',
+    '212' => '(?:8(?:5(?:25|30|6[0467]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[2-4]))',
     '213' => '(?:85(?:66|0[2357]|8[07-9]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]))',
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
@@ -206,7 +206,7 @@ our %ZIP_TABLE = (
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:7[027]|[58][058]|1[0-25]|2[0-35-7]|6[067]|4[0-2]|0[125-8]|3[039]))',
-    '224' => '(?:8(?:5(?:39|40|78|0[1-57]|8[058]|1[05]|5[01]|2[024])|6(?:01|8[68])))',
+    '224' => '(?:8(?:5(?:39|40|78|8[058]|1[05]|0[1-7]|5[01]|2[024])|6(?:01|8[68])))',
     '225' => '(?:85(?:[56]0|13|85|2[25]|0[1-38]|3[059]))',
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
@@ -222,7 +222,7 @@ our %ZIP_TABLE = (
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
     '242' => '(?:8(?:5(?:[58]5|77|0[27])|6(?:01|10)))',
-    '243' => '(?:(?:8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))|0(?:4(?:60|9[2-467]|8[02-79])|2(?:81|9[278])|19[23578]|392)))',
+    '243' => '(?:(?:0(?:4(?:60|9[2-467]|8[02-9])|2(?:81|9[278])|19[23578]|39[23])|8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))))',
     '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|60[12]))',
     '245' => '(?:8(?:5(?:[16]0|42|89|5[058]|7[57])|65[01]))',
     '246' => '(?:85(?:20|5[06]))',
@@ -230,7 +230,7 @@ our %ZIP_TABLE = (
     '248' => '(?:8(?:555|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
-    '251' => '(?:8(?:5(?:22|70|4[03]|8[018]|5[0158]|3[0134]|1[0135]|6[067]|0[125])|601))',
+    '251' => '(?:8(?:5(?:22|70|4[03]|1[0-35]|8[018]|5[0158]|3[0134]|6[067]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|2[0-25]|6[09]|8[025-8]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|8[13568]|9[258])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
@@ -239,23 +239,23 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|292)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
-    '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:09|86)|733))',
+    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
+    '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
-    '263' => '(?:8(?:5(?:[12]2|33|66|77|8[58]|5[05]|0[56])|733))',
+    '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
-    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
+    '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[235-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
     '271' => '(?:8(?:5(?:01|22|3[03]|[18][058]|5[157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:(?:85(?:01|73|4[03]|5[058]|2[02]|8[0158]|1[0-468]|6[01]|3[038])|01(?:88|9[35])))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
-    '277' => '(?:8(?:5(?:2[0-25]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|7[0-479]|6[1-69])|6(?:86|5[45]|6[16])))',
+    '277' => '(?:8(?:5(?:2[0-25]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|7[0-479]|6[1-689])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
-    '279' => '(?:8(?:5(?:41|67|70|0[1-6]|5[0358]|8[0-358]|2[1-35-79]|1[1269]|3[0-2])|6(?:01|86)))',
+    '279' => '(?:8(?:5(?:41|67|70|8[0-58]|0[1-6]|5[0358]|2[1-35-79]|1[1269]|3[0-2])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:11|55|88|0[15])|6(?:50|86)|701)|0195))',
     '284' => '(?:8555)',
@@ -288,7 +288,7 @@ our %ZIP_TABLE = (
     '312' => '(?:85(?:0[1-578]|1[01]))',
     '313' => '(?:8(?:6(?:[68]6|11)|511))',
     '314' => '(?:(?:8(?:501|655)|019[2-578]))',
-    '315' => '(?:(?:8(?:5(?:85|2[257]|1[1-368])|640)|0195))',
+    '315' => '(?:(?:8(?:5(?:85|2[2357]|1[1-368])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
     '318' => '(?:85(?:11|0[15]))',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
-    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[035689]|9[258])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
+    '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[035689]|9[2568])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
     '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -333,7 +333,7 @@ our %ZIP_TABLE = (
     '357' => '(?:85(?:[17]0|01|27|5[058]|8[58]))',
     '358' => '(?:85(?:[02]1|1[015]|[58][58]))',
     '359' => '(?:(?:8(?:5(?:[267]0|33|42|5[058]|1[013]|8[05]|0[157])|6(?:01|48|86))|11(?:9[23568]|8[089])))',
-    '360' => '(?:(?:8(?:5(?:[67]7|32|43|2[0-3]|1[25]|8[05]|0[12]|5[589])|6(?:11|20|0[18]))|019[2-7]))',
+    '360' => '(?:(?:8(?:5(?:[67]7|32|43|2[0-3]|1[25]|8[05]|0[12]|5[589])|6(?:20|1[16]|0[18]))|019[2-7]))',
     '361' => '(?:8(?:5(?:[58]5|39|1[013]|0[3-8])|60[1-4]))',
     '362' => '(?:8(?:5(?:[67]7|42|3[19]|2[013]|8[58]|0[1248]|5[035]|1[017])|688))',
     '363' => '(?:8(?:5(?:10|0[159]|5[58])|601))',
@@ -355,14 +355,14 @@ our %ZIP_TABLE = (
     '379' => '(?:(?:2(?:1(?:8[014-7]|9[2-578])|39[258]|29[28])|1(?:29[78]|[16]92|393|498)|0(?:19[235-7]|292)))',
     '380' => '(?:8(?:5(?:0[1-35-8]|8[0-689]|2[014-6]|7[0235-7]|6[015-8]|5[0-3578]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|77|0[158]|2[25]|8[268]|6[068]|4[08]|1[0-24]|3[039])|7(?:10|9[4-8])))',
     '381' => '(?:(?:8(?:5(?:1[015]|5[0168]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08])|6(?:02|86)|793)|0(?:2(?:88|9[235-8])|19[23]|49[78])|22(?:8[0-35-9]|9[258])|4(?:19[23]|393)))',
-    '382' => '(?:8(?:5(?:33|55|77|8[578]|1[0-2]|0[258])|633))',
+    '382' => '(?:8(?:5(?:33|55|77|0[2358]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
     '384' => '(?:(?:8(?:5(?:[01]1|58|8[58])|605)|0(?:69[2578]|393|798)|(?:11|22)92))',
     '385' => '(?:8(?:5(?:[01]1|22|33|8[568]|5[58])|6(?:[01]1|86)))',
     '386' => '(?:(?:8(?:5(?:[67]7|22|43|5[135]|8[458]|1[01]|0[15])|6(?:24|0[189]|8[3568]|6[68]|3[48]|1[01])|7(?:05|20|1[05]))|0(?:49[23578]|39[36]|[15]92)|1(?:19[23]|298)|2292))',
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
-    '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2[1257]92))',
+    '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
     '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|2[0358]|4[013]|1[0158]|3[01359]|[56][05])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[2-47]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
     '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[125])|0(?:29[2-7]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
@@ -399,7 +399,7 @@ our %ZIP_TABLE = (
     '424' => '(?:(?:8(?:6(?:48|50|0[1-3]|7[78]|3[1367]|[68][68]|1[01]|2[024])|7(?:82|3[04]|2[0147]|5[0-25]|6[07]|0[18]|1[579])|5(?:66|0[23]|5[058]|1[01]))|0(?:19[23]|292)))',
     '425' => '(?:8(?:5(?:[58]5|[67]0|11|22|33|0[1-358])|6(?:11|8[06])|7(?:11|0[18])))',
     '426' => '(?:(?:8(?:6(?:01|7[07]|3[1-38]|1[27]|4[026]|6[2368])|5(?:39|43|66|1[015]|0[13]|7[057])|7(?:11|22))|0292))',
-    '427' => '(?:(?:8(?:5(?:22|41|55|0[12589]|8[18]|1[0-2])|6(?:86|0[12]))|019[356]))',
+    '427' => '(?:(?:8(?:5(?:22|41|55|0[12589]|8[18]|1[0-2])|6(?:86|0[12])|711)|019[356]))',
     '428' => '(?:(?:8(?:6(?:86|5[0-2])|50[1-3])|0192))',
     '430' => '(?:(?:8(?:5(?:[246]0|7[057]|5[358]|8[0578]|3[036]|1[01])|6(?:11|20|7[058]|8[0679]|3[09]|6[57]|5[02-5]))|089[78]))',
     '431' => '(?:(?:0(?:49[2-6]|29[258]|19[23]|395)|3(?:19[2-6]|39[23]|492)|1(?:39[2-5]|49[5-7])|(?:22|41)95))',
@@ -417,8 +417,8 @@ our %ZIP_TABLE = (
     '443' => '(?:(?:8(?:5(?:[05]5|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
-    '446' => '(?:8(?:5(?:40|1[124578]|5[058]|3[35]|0[1-8]|8[58]|2[0-6])|6(?:35|41|86|0[12])))',
-    '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
+    '446' => '(?:8(?:5(?:40|2[0-356]|1[124578]|5[058]|3[35]|0[1-8]|8[58])|6(?:35|41|86|0[12])))',
+    '447' => '(?:8(?:5(?:0[1-35-8]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
     '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
@@ -486,7 +486,7 @@ our %ZIP_TABLE = (
     '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|1[0-58]|5[023578]|8[568]|7[0178]|2[0-2468]|0[1-3578]|6[06-8])|6(?:[01]1|86|6[6-8]|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[235])|039[235-8]))',
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
     '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|8[018]|4[3-9]|6[67]|1[12568]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
-    '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
+    '517' => '(?:(?:0(?:59[235]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:29[2-68]|49[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[3-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|1[0-356]|7[057]|5[058])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
@@ -518,7 +518,7 @@ our %ZIP_TABLE = (
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
     '549' => '(?:85(?:11|22|85))',
-    '550' => '(?:8(?:5(?:10|27|41|8[05-7]|5[025]|6[67]|7[0578]|3[08]|0[1-358])|6(?:59|60)))',
+    '550' => '(?:8(?:5(?:10|27|41|8[05-7]|6[67]|7[0578]|3[08]|0[1-358]|5[0258])|6(?:59|60)))',
     '551' => '(?:85[015]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:67|1[1-3]|0[13]|5[0358]|8[58])|739))',
@@ -527,7 +527,7 @@ our %ZIP_TABLE = (
     '556' => '(?:8(?:5(?:[38]5|1[056]|0[13]|5[058])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
-    '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|58|0[1245])|729))',
+    '559' => '(?:8(?:5(?:5[035689]|1[019]|8[58]|0[126]|6[01])|6(?:11|58|0[1245])|729))',
     '560' => '(?:85(?:13|79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[23]0|01|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
@@ -535,12 +535,12 @@ our %ZIP_TABLE = (
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
     '565' => '(?:85(?:11|40|85))',
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
-    '567' => '(?:8(?:5(?:[34]0|57|1[015]|2[0135]|8[58]|6[57]|7[08]|0[1257])|6(?:51|80)))',
+    '567' => '(?:8(?:5(?:[34]0|57|2[0135]|8[58]|6[57]|1[015-8]|7[08]|0[1257])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
     '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:[24]0|33|86)))',
     '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
-    '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|6(?:54|66))|10(?:[34]0|1[03]|0[1478])|019[356]))',
+    '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[0-2])|6(?:54|66))|10(?:[34]0|1[03]|0[1478])|019[356]))',
     '574' => '(?:85(?:[58]5|01|3[0-4]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
@@ -549,7 +549,7 @@ our %ZIP_TABLE = (
     '579' => '(?:8502)',
     '580' => '(?:8(?:50[1-5]|601))',
     '581' => '(?:8(?:5(?:11|39|85|0[25]|5[58])|686))',
-    '582' => '(?:85(?:01|55|8[25]))',
+    '582' => '(?:85(?:01|55|8[258]))',
     '583' => '(?:85(?:01|22|63|3[3-5]|8[0358]|5[058]))',
     '584' => '(?:8(?:5(?:[013]1|22|40|85)|651))',
     '585' => '(?:85(?:01|85|5[05]))',
@@ -575,7 +575,7 @@ our %ZIP_TABLE = (
     '606' => '(?:85(?:11|22|36|40|[58][58]|0[1257]))',
     '607' => '(?:85[017]1)',
     '610' => '(?:(?:0(?:3(?:80|9[3-7])|19[256]|28[179])|119[258]))',
-    '611' => '(?:8(?:5(?:01|55|8[58])|660))',
+    '611' => '(?:8(?:5(?:[02]1|55|8[58])|660))',
     '612' => '(?:8(?:5(?:01|22|77|85|3[03]|5[058]|1[15])|6(?:02|60|77|86)))',
     '613' => '(?:8585)',
     '614' => '(?:85(?:[01]1|88))',
@@ -638,7 +638,7 @@ our %ZIP_TABLE = (
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:[01]1|[58]5|22)|6(?:66|8[68]))|1(?:49[2-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:01|85)|686))',
-    '675' => '(?:(?:8(?:5(?:22|33|77|88|1[019]|6[67]|5[58]|0[15])|6(?:11|75|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
+    '675' => '(?:(?:8(?:5(?:22|33|77|88|6[5-7]|1[019]|5[58]|0[15])|6(?:11|75|8[68]))|01(?:8[0-68]|9[23568])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
     '677' => '(?:851[01])',
     '678' => '(?:(?:1(?:29[257]|19[58])|0(?:19[235]|292)|85(?:43|85)))',
@@ -680,7 +680,7 @@ our %ZIP_TABLE = (
     '717' => '(?:8501)',
     '718' => '(?:(?:85(?:[135]0|01|85)|0392))',
     '719' => '(?:(?:0(?:39[238]|19[25]|295)|3(?:19[2-57]|292)|119[235-8]))',
-    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|0[1-47-9]|2[024-7])|6(?:01|50|3[6-9]|4[01357]))|039[278]|219[25]))',
+    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|0[1-47-9]|2[024-7])|6(?:01|3[6-8]|5[02]|4[01357]))|039[278]|219[25]))',
     '721' => '(?:8(?:5(?:7[5-7]|6[47]|2[28]|8[568]|4[0135]|1[0145]|5[01568]|0[125])|6(?:31|88|0[17])))',
     '722' => '(?:(?:8(?:5(?:10|0[1-35-8])|60[1245])|2(?:19[238]|49[2-4]|39[23])|1(?:19[23]|[47]92)|039[23]))',
     '723' => '(?:8(?:5(?:01|20|55|1[0-25])|6(?:01|86|1[01])))',
@@ -811,7 +811,7 @@ our %ZIP_TABLE = (
     '850' => '(?:8(?:5(?:2[0-35]|8[0568]|1[0-258]|7[057]|5[0158]|0[13-8]|6[0367]|3[0167]|4[013578])|6(?:22|45|50|7[78]|1[018]|6[268]|8[5-8]|0[236])))',
     '851' => '(?:(?:0(?:49[2-478]|19[358]|39[25]|592)|2(?:1(?:85|9[5-8])|29[28]|492)|3(?:39[24]|[25]92)))',
     '852' => '(?:8(?:5(?:32|66|77|88|1[015]|0[17-9]|4[24]|5[58]|2[0-378])|601|794))',
-    '853' => '(?:(?:8(?:50[12]|601)|(?:06|2[23])92))',
+    '853' => '(?:(?:(?:06|31|2[23])92|8(?:50[12]|601)))',
     '854' => '(?:(?:8(?:5(?:40|55|0[19])|6(?:01|50|66))|0(?:69[26-8]|59[235]|[24]92)))',
     '855' => '(?:8(?:5(?:01|5[05])|686))',
     '856' => '(?:8(?:5(?:[58]5|16|77|6[0-28])|6(?:70|86|0[19])))',
@@ -848,7 +848,7 @@ our %ZIP_TABLE = (
     '887' => '(?:8(?:585|686))',
     '888' => '(?:8555)',
     '889' => '(?:(?:1(?:49[2358]|69[2356]|99[4-7]|[18]92|795)|0(?:69[235-8]|59[25]|[13]92)|(?:4[2-5]|2[14])92))',
-    '890' => '(?:8(?:5(?:6[05-7]|3[0-35]|1[0-257]|0[1-9]|8[015689]|4[013-5]|2[0-57]|5[0258]|7[014578])|6(?:[68]6|10|0[13])|7(?:60|9[48])))',
+    '890' => '(?:8(?:5(?:6[05-7]|3[0-35]|1[0-257]|0[1-9]|8[015689]|4[013-5]|2[0-57]|5[0258]|7[014578])|6(?:[68]6|10|0[134])|7(?:60|9[48])))',
     '891' => '(?:(?:0(?:1(?:8[02-46-9]|9[2-8])|49[378]|[67]92)|3(?:19[2-68]|69[23]|79[23])|1(?:39[2-5]|[15]92)|9(?:29[2-6]|192)|(?:[46]2|7[16])92|2(?:39[36]|192)|8293))',
     '892' => '(?:8(?:5(?:20|4[03]|1[25]|8[568]|5[058]|6[367]|3[01359]|0[125])|6(?:11|26|33|50|77|88|0[13])))',
     '893' => '(?:(?:1(?:19[28]|69[23]|298)|8(?:5(?:10|0[12])|611)|(?:02|2[34])92))',
@@ -889,7 +889,7 @@ our %ZIP_TABLE = (
     '930' => '(?:(?:8(?:5(?:2[0-25-7]|4[03-58]|0[14-9]|6[0-35-7]|3[0-35-9]|8[0135-9]|1[0-35-8]|7[013578]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|8[0167]|1[01]|6[06-8]))|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
     '931' => '(?:8(?:5(?:33|62|2[23]|4[03]|7[17]|0[128]|[58][58]|1[0157])|6(?:01|88)))',
     '932' => '(?:(?:8(?:5(?:40|67|75|1[0-258]|3[38]|5[0158]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|29[238]|19[38])))',
-    '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|0[126-8]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|1[01]|0[1356])|7(?:77|88))|0(?:39[235-8]|19[235]|29[35])))',
+    '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|3[0-3578]|5[08]|2[035-8]|0[125-8])|6(?:[28]8|66|1[01]|0[1356])|7(?:77|88))|0(?:39[235-8]|19[235]|29[35])))',
     '934' => '(?:8(?:5(?:22|77|6[78]|3[14]|8[058]|0[12]|5[08]|1[15])|6(?:[15]1|8[68])))',
     '935' => '(?:8(?:5(?:01|55|3[15])|6(?:01|86)))',
     '936' => '(?:8(?:5(?:36|77|0[127]|[58][58])|6(?:86|0[18])))',
@@ -899,7 +899,7 @@ our %ZIP_TABLE = (
     '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2]))|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
-    '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|8[58]|5[125]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
+    '943' => '(?:(?:8(?:5(?:61|1[025]|5[1258]|4[045]|3[0134]|2[0-25]|8[58]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
     '944' => '(?:(?:8(?:5(?:01|88|5[05])|6(?:01|86))|0192))',
     '945' => '(?:(?:8(?:5(?:[01]1|[38]5|40|5[58])|6(?:[01]1|88))|1(?:39[23578]|[15]95)|0(?:19[2-4]|39[57])))',
     '946' => '(?:(?:8(?:513|601)|0292))',
@@ -934,10 +934,10 @@ our %ZIP_TABLE = (
     '975' => '(?:8(?:585|686))',
     '976' => '(?:85(?:01|10))',
     '979' => '(?:(?:0(?:19[25-8]|69[56])|2(?:39[2-4]|195|792)|1(?:[135]92|495)))',
-    '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|0[158]|2[1569]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|7[17]|3[1-36-9]|2[12])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
+    '980' => '(?:(?:8(?:4(?:7[78]|4[1-35-8]|8[014-8]|0[1-36-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|7\d|4[346]|0[158]|2[1569]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[157])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|2[23]|6[03]|5[0-26-8]|0[25]|7[07]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
-    '983' => '(?:8(?:5(?:43|85|6[0257]|0[1247]|3[367]|2[023]|1[1-37]|5[1256])|6(?:01|22)|477))',
+    '983' => '(?:8(?:5(?:43|85|0[1247]|2[03]|6[057]|3[367]|1[1-37]|5[1256])|6(?:01|22)|477))',
     '984' => '(?:8(?:5(?:0[135]|7[057]|2[25]|6[0178]|8[0458]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:77|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
